const baseColorList = [
  "#ED8796",
  "#A6DA95",
  "#EED49F",
  "#8AADF4",
  "#F5BDE6",
  "#8BD5CA",
  "#f5a97f",
];

const baseBarColors = {
  enabled: false,
  lightness: 0.5,
  saturation: 0.5,
  alpha: 1,
  systemColor: "highlightColor",
  systemColorSet: "Window",
  custom: "#013eff",
  list: baseColorList,
  reverseList: false,
  followColor: 0,
  saturationEnabled: false,
  lightnessEnabled: false,
  sourceType: 7,
  smoothGradient: true,
  colorsOrientation: 0,
  image: {
    source: "",
    fillMode: 2
  },
  hueStart: 0,
  hueEnd: 360,
};

const baseWaveFillColors = {
  enabled: false,
  lightness: 0.5,
  saturation: 0.5,
  alpha: 0.3,
  systemColor: "highlightColor",
  systemColorSet: "Window",
  custom: "#013eff",
  list: baseColorList,
  reverseList: false,
  followColor: 0,
  saturationEnabled: false,
  lightnessEnabled: false,
  sourceType: 7,
  smoothGradient: true,
  colorsOrientation: 0,
  image: {
    source: "",
    fillMode: 2
  },
  hueStart: 0,
  hueEnd: 360,
};

const baseInactiveBlockColors = {
  enabled: false,
  lightness: 0.5,
  saturation: 0.5,
  alpha: 0.3,
  systemColor: "textColor",
  systemColorSet: "Window",
  custom: "#013eff",
  list: baseColorList,
  reverseList: false,
  followColor: 0,
  saturationEnabled: false,
  lightnessEnabled: false,
  sourceType: 1,
  smoothGradient: true,
  colorsOrientation: 0,
  image: {
    source: "",
    fillMode: 2
  },
  hueStart: 0,
  hueEnd: 360,
};
